/*
	test.lsl
	Sample Leveller shape list file for testing
	Copyright 1998, 1999, 2000 Daylon Graphics Ltd.
*/

// A comment.

/* A one-line block comment. */

/*
	A multi-line block comment.
	This is the second line.
	The '/*' and '//' symbols must have whitespace around them.
*/


/*
	The 'version' keyword specifies what version file this is.
	Leveller will check this value to avoid loading shape lists 
	that it is incompatible with. This keyword should be used 
	as early as possible. For compatability with older versions 
	of Leveller, avoid using a version value greater than you need.
*/
version 1.2

/*
	Version 1.1 added bitmap texturing to boxes.
	Version 1.2 added 'rotate' and 'translate' keywords, 
				and the ability to specify boxes by corner points.
*/

/*
    Available shapes are lines, triangles, and boxes.
	Usually, you will want to create .lsl files
	procedurally as part of an application's export 
	feature, although small .lsl files are not hard 
	to create by hand.

	All geometry is expressed in grid coordinates.
	The origin of space is the center of the heightfield.
	The X/Y/Z axes follow POV-Ray convention (+Y = up, +Z = into screen).

	Basic shape declaration syntax:

	shapetype -- line, triangle, or box
	{
		[ name str ]		// e.g.: name "My cool shape"
		[ color r, g, b ]   // e.g.: color 0, 1, 0  // 100% green
		... geometry
		[ origin x y z ] // e.g: origin 1 0 0 // set object's position to 1,0,0
		[ size xs, ys, zs ] // e.g.: scale 2, 2, 2 // enlarge 200% uniformly
		[ rotate angle x y z ] // e.g.: rotate 90 0 1 0 // rotate 90 degrees around Y axis
		[ translate x y z ] // e.g: translate 0 1 0 shift object 1.0 units up along Y axis
		[ orient right, up, forward ] // Orientation of object along matrix vectors
	}

	For quote symbols within strings, use \", not " by itself.
	Names are not currently used by Leveller, but this may change 
	in the future, so you may want to define them.

	Default color is black.

	Specific shape declarations:
	
	line  // A one-pixel thick wireframe line
	{
		p1 x, y, z	// Location of line's starting point
		p2 x, y, z  // Location of endpoint
	}

	triangle // A three-point polygon
	{
		p1 x, y, z	// Location of point #1
		p2 x, y, z  //    "    "    "    #2
		p3 x, y, z  //    "    "    "    #3
	}


	box // A 3D parallelogram
	{
		[ p1 x, y, z  p2 x, y, z ]  // location of box's corners
		[ origin x, y, z ]	// Location of box's center
		[ size sx, sy, sz ]	// Box's size as scaling factors
		[ orient right, up, forward ] // Orientation of box
		[ imagemap faceIDlist, texturefile(s) ] // Bitmap textures
		// Face IDs: 0=front, 1=left, 2=right, 3=back, 4=top, 5=bottom
		// A '1' in the faceIDlist indicates a textured face.
		// example: imagemap "111010" "front.tga" "left.tga" "right.tga" "top.tga"
		// Texture sizes must currently be in powers of 2.
		// If bitmap filenames are relative (i.e., have no drive letter),
		// then they are relative to the directory that the LSL file is in.

		// Note: it is most efficient to use the same imagemap repeatedly, 
		// since it will be physically stored only once and shared amongst 
		// all usages, even across documents.
	}

	If p1 defined, p2 must be defined.
	Default origin is 0, 0, 0.
	Default size is 1, 1, 1.
	Default orientation is 1, 0, 0
	                       0, 1, 0
						   0, 0, 1
	Default texture is no texture.

	Box color is applied to one face and then progressively darkened 
	for remaining faces. This makes it easier to distinguish the
	box's edges.
*/




// A red line shape.
line
{
	name "Test line"
	color 1, 0, 0
	p1 0, 0, 0
	p2 10, 20, 30
}

// A cyan line shape, described on one instruction line.
line { color 0, 1, 1 p1 0, 10, 0 p2 10, 20, -40 }

// A triangle.
triangle
{
	color 1, 0, 0
	p1 0, 0, 0
	p2 10, 10, 10
	p3 -10, 10, 10
}


// A box shape.
box
{
	name "Test box"
	color 1, 0, 0
	origin 32, 0, 32
	size 5, 10, 2
	// orient 1, 0, 0   0, 1, 0   0, 0, 1  // default
	orient 0, 1, 0   -1, 0, 0   0, 0, 1  // 90 ccw around z axis
}

/*
// A textured building in the center of the scene.
box
{
	origin 0, 10, 0
	size 5, 20, 5
	imagemap "111110"
		"tx/bldg/bldg5.tga" 
		"tx/bldg/bldg5.tga" 
		"tx/bldg/bldg5.tga" 
		"tx/bldg/bldg5.tga" 
		"tx/bldg/top.tga"
}
*/
